@@ -27,21 +27,32 @@ from .health import *
 
 def register():
     Pool.register(
+        OperationalArea,
+        OperationalSector,
+        DomiciliaryUnit,
+        Occupation,
+        Ethnicity,
+        PartyPatient,
+        PartyAddress,
         DrugDoseUnits,
         MedicationFrequency,
         DrugForm,
         DrugRoute,
-        Occupation,
-        Ethnicity,
         MedicalSpecialty,
+        HealthInstitution,
+        HealthInstitutionSpecialties,
+        HealthInstitutionOperationalSector,
+        HealthInstitutionO2M,
+        HospitalBuilding,
+        HospitalUnit,
+        HospitalOR,
+        HospitalWard,
+        HospitalBed,
         HealthProfessional,
         HealthProfessionalSpecialties,        
         PhysicianSP,
-        OperationalArea,
-        OperationalSector,
         Family,
         FamilyMember,
-        DomiciliaryUnit,
         MedicamentCategory,
         Medicament,
         PathologyCategory,
@@ -52,8 +63,6 @@ def register():
         InsurancePlan,
         Insurance,
         AlternativePersonID,
-        PartyPatient,
-        PartyAddress,
         ProductCategory,
         ProductTemplate,
         Product,
@@ -72,11 +81,6 @@ def register():
         SecondaryCondition,
         DiagnosticHypothesis,
         SignsAndSymptoms,
-        HospitalBuilding,
-        HospitalUnit,
-        HospitalOR,
-        HospitalWard,
-        HospitalBed,
         module='health', type_='model')
     Pool.register(
         OpenAppointmentReport,
